@@ -10,15 +10,18 @@ import xml.etree.ElementTree as ET
 from appium.webdriver import WebElement
 from icecream import ic
 from selenium.common import NoSuchDriverException, InvalidSessionIdException, WebDriverException, \
-    StaleElementReferenceException, NoSuchElementException
+    StaleElementReferenceException, NoSuchElementException, TimeoutException
 from selenium.types import WaitExcTypes
 from selenium.webdriver import ActionChains
 from selenium.webdriver.common.actions import interaction
 from selenium.webdriver.common.actions.action_builder import ActionBuilder
 from selenium.webdriver.common.actions.pointer_input import PointerInput
 from selenium.webdriver.remote.shadowroot import ShadowRoot
+from selenium.webdriver.support.wait import WebDriverWait
+from selenium.webdriver.support import expected_conditions as EC
 
 from shadowstep.element.base import ElementBase
+from shadowstep.utils import conditions
 from shadowstep.utils.utils import find_coordinates_by_vector
 
 # Configure the root logger (basic configuration)
@@ -573,6 +576,8 @@ class Element(ElementBase):
             stacktrace=traceback.format_stack()
         )
 
+
+
     # Override
     def is_displayed(self) -> bool:
         """Whether the element is visible to a user.
@@ -654,6 +659,22 @@ class Element(ElementBase):
             stacktrace=traceback.format_stack()
         )
 
+    def is_not_within_screen(self) -> bool:
+        """Checks whether the element is not within the visible screen bounds.
+
+        Returns:
+            bool: True if element is not displayed or outside screen bounds.
+        """
+        self.logger.info(f"{inspect.currentframe().f_code.co_name}")
+        try:
+            return not self.is_within_screen()
+        except GeneralElementException as error:
+            self.logger.warning(f"is_not_within_screen fallback due to: {error}")
+            return True
+        except Exception as error:
+            self.logger.warning(f"is_not_within_screen unexpected error: {error}")
+            return True
+
     def is_selected(self) -> bool:
         """Returns whether the element is selected.
 
@@ -2106,3 +2127,146 @@ class Element(ElementBase):
         self.logger.info(f"{inspect.currentframe().f_code.co_name}")
         parent_xpath = self._get_xpath()
         return f"{parent_xpath}/*[{index}]"
+
+
+    def wait(self, timeout: int = 10, poll_frequency: float = 0.5) -> bool:
+        """Waits for the element to appear (present in DOM).
+
+        Args:
+            timeout (int): Timeout in seconds.
+            poll_frequency (float): Frequency of polling.
+
+        Returns:
+            bool: True if the element is found, False otherwise.
+        """
+        self.logger.info(f"{inspect.currentframe().f_code.co_name}")
+        try:
+            resolved_locator = self.handle_locator(self.locator, self.contains)
+            if not resolved_locator:
+                self.logger.error("Resolved locator is None or invalid")
+                return False
+            WebDriverWait(self.base.driver, timeout, poll_frequency).until(
+                conditions.present(resolved_locator)
+            )
+            return True
+        except TimeoutException:
+            return False
+
+    def wait_visible(self, timeout: int = 10, poll_frequency: float = 0.5) -> bool:
+        """Waits until the element is visible.
+
+        Args:
+            timeout (int): Timeout in seconds.
+            poll_frequency (float): Frequency of polling.
+
+        Returns:
+            bool: True if the element becomes visible, False otherwise.
+        """
+        self.logger.info(f"{inspect.currentframe().f_code.co_name}")
+        try:
+            resolved_locator = self.handle_locator(self.locator, self.contains)
+            if not resolved_locator:
+                self.logger.error("Resolved locator is None or invalid")
+                return False
+
+            WebDriverWait(self.base.driver, timeout, poll_frequency).until(
+                conditions.visible(resolved_locator)
+            )
+            return True
+        except TimeoutException:
+            return False
+
+    def wait_clickable(self, timeout: int = 10, poll_frequency: float = 0.5) -> bool:
+        """Waits until the element is clickable.
+
+        Args:
+            timeout (int): Timeout in seconds.
+            poll_frequency (float): Frequency of polling.
+
+        Returns:
+            bool: True if the element becomes clickable, False otherwise.
+        """
+        self.logger.info(f"{inspect.currentframe().f_code.co_name}")
+        try:
+            resolved_locator = self.handle_locator(self.locator, self.contains)
+            if not resolved_locator:
+                self.logger.error("Resolved locator is None or invalid")
+                return False
+
+            WebDriverWait(self.base.driver, timeout, poll_frequency).until(
+                conditions.clickable(resolved_locator)
+            )
+            return True
+        except TimeoutException:
+            return False
+
+    def wait_for_not(self, timeout: int = 10, poll_frequency: float = 0.5) -> bool:
+        """Waits until the element is no longer present in the DOM.
+
+        Args:
+            timeout (int): Timeout in seconds.
+            poll_frequency (float): Frequency of polling.
+
+        Returns:
+            bool: True if the element disappears, False otherwise.
+        """
+        self.logger.info(f"{inspect.currentframe().f_code.co_name}")
+        try:
+            resolved_locator = self.handle_locator(self.locator, self.contains)
+            if not resolved_locator:
+                self.logger.error("Resolved locator is None or invalid")
+                return True
+            WebDriverWait(self.base.driver, timeout, poll_frequency).until(
+                conditions.not_present(resolved_locator)
+            )
+            return True
+        except TimeoutException:
+            return False
+
+    def wait_for_not_visible(self, timeout: int = 10, poll_frequency: float = 0.5) -> bool:
+        """Waits until the element becomes invisible.
+
+        Args:
+            timeout (int): Timeout in seconds.
+            poll_frequency (float): Polling frequency.
+
+        Returns:
+            bool: True if the element becomes invisible, False otherwise.
+        """
+        self.logger.info(f"{inspect.currentframe().f_code.co_name}")
+        try:
+            resolved_locator = self.handle_locator(self.locator, self.contains)
+            if not resolved_locator:
+                self.logger.error("Resolved locator is None or invalid")
+                return True
+            WebDriverWait(self.base.driver, timeout, poll_frequency).until(
+                conditions.not_visible(resolved_locator)
+            )
+            return True
+        except TimeoutException:
+            return False
+
+    def wait_for_not_clickable(self, timeout: int = 10, poll_frequency: float = 0.5) -> bool:
+        """Waits until the element becomes not clickable.
+
+        Args:
+            timeout (int): Timeout in seconds.
+            poll_frequency (float): Polling frequency.
+
+        Returns:
+            bool: True if the element becomes not clickable, False otherwise.
+        """
+        self.logger.info(f"{inspect.currentframe().f_code.co_name}")
+        try:
+            resolved_locator = self.handle_locator(self.locator, self.contains)
+            if not resolved_locator:
+                self.logger.error("Resolved locator is None or invalid")
+                return True
+            WebDriverWait(self.base.driver, timeout, poll_frequency).until(
+                conditions.not_clickable(resolved_locator)
+            )
+            return True
+        except TimeoutException:
+            return False
+
+
